import 'package:equatable/equatable.dart';

abstract class RestorePasswordState extends Equatable {
  const RestorePasswordState();

  @override
  List<Object> get props => [];
}

class RestorePasswordInitial extends RestorePasswordState {}

class RestorePasswordLoading extends RestorePasswordState {}

class RestorePasswordSuccess extends RestorePasswordState {}

class RestorePasswordFailure extends RestorePasswordState {
  final String error;

  const RestorePasswordFailure(this.error);

  @override
  List<Object> get props => [error];
}

class RestorePasswordFieldsState extends RestorePasswordState {
  final bool areFieldsFilled;

  const RestorePasswordFieldsState(this.areFieldsFilled);

  @override
  List<Object> get props => [areFieldsFilled];
}
